==> sdata-plugin-scripts-1.0.34.tgz: package/src/run.js <==
#!/usr/bin/env node
import { start, plugin, startOnline, pluginDev, isVue } from "./getArgs";
const childProcess = require("child_process");
const cwd = process.cwd();
const fs = require("fs");
const configJson = require(cwd + "/config.json");
const pluginType = configJson.type;
const templateType = configJson.toLowerCase() === 'react' ? 'react' : 'vue';

if(!fs.existsSync(cwd + '/output')){
  fs.mkdirSync(cwd + '/output')
}

if(start){
  if(isVue){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} VUE_CLI_SERVICE_CONFIG_PATH=${__dirname}/vue.config.js vue-cli-service serve`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }else{
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/start.js`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }
}

if(startOnline){
  if(isVue){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} VUE_APP_ONLINE_DEVELOPMENT_MODE=true VUE_CLI_SERVICE_CONFIG_PATH=${__dirname}/vue.config.js vue-cli-service serve`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }else{
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} REACT_APP_ONLINE_DEVELOPMENT_MODE=true FAST_REFRESH=false node ${__dirname}/scripts/start.js`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }
}

if(plugin || pluginDev){
  childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/predev`, {
    async: false,
    stdio: "inherit",
    stderr: "inherit",
  })

  if(!pluginDev){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/prebuild`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }

  if(isVue){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} VUE_APP_ONLINE_DEVELOPMENT_MODE=${pluginDev} VUE_CLI_SERVICE_CONFIG_PATH=${__dirname}/vue.config.js vue-cli-service build`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }else{
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} REACT_APP_NEEDSOURCEMAP=false node ${__dirname}/scripts/build.js`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }

  childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/genPlugin.js --source=${pluginDev?'true':'false'}`, {
    async: false,
    stdio: "inherit",
    stderr: "inherit",
  })
}

==> sdata-plugin-scripts-1.0.35.tgz: package/src/run.js <==
#!/usr/bin/env node
import { start, plugin, startOnline, pluginDev, isVue } from "./getArgs";
const childProcess = require("child_process");
const cwd = process.cwd();
const fs = require("fs");
const configJson = require(cwd + "/config.json");
const pluginType = configJson.type;
const templateType = configJson.templateType.toLowerCase() === 'react' ? 'react' : 'vue';

if(!fs.existsSync(cwd + '/output')){
  fs.mkdirSync(cwd + '/output')
}

if(start){
  if(isVue){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} VUE_CLI_SERVICE_CONFIG_PATH=${__dirname}/vue.config.js vue-cli-service serve`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }else{
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/start.js`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }
}

if(startOnline){
  if(isVue){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} VUE_APP_ONLINE_DEVELOPMENT_MODE=true VUE_CLI_SERVICE_CONFIG_PATH=${__dirname}/vue.config.js vue-cli-service serve`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }else{
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} REACT_APP_ONLINE_DEVELOPMENT_MODE=true FAST_REFRESH=false node ${__dirname}/scripts/start.js`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }
}

if(plugin || pluginDev){
  childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/predev`, {
    async: false,
    stdio: "inherit",
    stderr: "inherit",
  })

  if(!pluginDev){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/prebuild`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }

  if(isVue){
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} VUE_APP_ONLINE_DEVELOPMENT_MODE=${pluginDev} VUE_CLI_SERVICE_CONFIG_PATH=${__dirname}/vue.config.js vue-cli-service build`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }else{
    childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} REACT_APP_NEEDSOURCEMAP=false node ${__dirname}/scripts/build.js`, {
      async: false,
      stdio: "inherit",
      stderr: "inherit",
    })
  }

  childProcess.execSync(`cross-env PLUGIN_TYPE=${pluginType} TEMPLATE_TYPE=${templateType} node ${__dirname}/scripts/genPlugin.js --source=${pluginDev?'true':'false'}`, {
    async: false,
    stdio: "inherit",
    stderr: "inherit",
  })
}
